@@ -7,6 +7,15 @@ import dash_html_components as html
 from plotly.subplots import make_subplots
 import numpy as np
 
+colors = {
+    'background': 'SteelBlue',
+    'text': 'White',
+    'controls': '#DDDDDD',
+    'buttons': 'Orange'
+}
+
+
+
 def app_parameter(label, appid, inputtype, value, size='20'):
     """
     A label and a Input control, as elements of a table row
@@ -158,3 +167,38 @@ def merge_plots(figures, cols=1, shared_xaxes=True, shared_yaxes=True, subplot_t
         add_plot(bigfig, fig, row=n // cols + 1, col=n % cols + 1)
     bigfig.update_layout(title_text=title_text, showlegend=False)
     return bigfig
+
+def make_top_banner(title):
+    logo = html.Div(
+        style={'textAlign': 'center', 'color': colors['controls'], 'width': '5%', 'display': 'inline-block'},
+        children=[
+            html.Img(src='https://randall-romero.github.io/econometria/_static/r2-logo.png',
+                     width='100%',
+                     style={'margin-left': '0px',
+                            'margin-top': '2px',
+                            'margin-bottom': '2px'
+                            })])
+    header = html.Div(
+        style={'textAlign': 'center', 'color': colors['controls'], 'width': '93%', 'display': 'inline-block'},
+        children=[
+            html.H2(id='title',
+                    children=title,
+                    style={'textAlign': 'center', 'color': colors['text']})])
+
+    return logo, header
+
+def make_bottom_banner(name_of_demo, width=25):
+    footer = html.Div(
+        style={'textAlign': 'center', 'color': colors['controls'], 'width': '100%', 'display': 'inline-block'},
+        children=[
+            html.Div(style={'textAlign': 'center', 'color': colors['controls'], 'width': f'{width}%', 'display': 'inline-block'},
+                     children=[html.P(name_of_demo,
+                                      style={'textAlign': 'center', 'color': colors['text'] ,'marginTop' :10})]),
+            html.Div(style={'textAlign': 'left', 'color': colors['controls'], 'width': f'{100-width}%', 'display': 'inline-block'},
+                     children=[html.A(children='Randall Romero Aguilar',
+                                      href='http://randall-romero.com',
+                                      style={'textAlign': 'left', 'color': colors['text'] ,'marginBottom' :20})])
+        ]
+    )
+
+    return footer
