@@ -12,7 +12,7 @@ theoretical properties of ARMA(p, q) process, as well as their estimated counter
     7. MA inverse roots
 
 Randall Romero Aguilar
-2016-2020
+2016-2021
 """
 
 
@@ -26,7 +26,8 @@ import plotly.express as px
 import plotly.graph_objects as go
 import webbrowser
 
-from macrodemos.common_components import app_parameter, app_parameter_row, editable_cell_format
+from macrodemos.common_components import app_parameter, app_parameter_row, editable_cell_format, \
+    colors, make_bottom_banner, make_top_banner
 
 import numpy as np
 from numpy.polynomial import Polynomial as P
@@ -44,12 +45,6 @@ from statsmodels.tsa.stattools import acf, pacf # autocorrelation and partial au
 # Esta parte controla asuntos de estética de la página
 external_stylesheets = ['https://codepen.io/chriddyp/pen/bWLwgP.css']
 
-colors = {
-    'background': 'SteelBlue',
-    'text': 'White',
-    'controls': '#DDDDDD',
-    'buttons': 'Orange'
-}
 
 # Esta función se utiliza para calcular la varianza del proceso ARMA
 
@@ -484,8 +479,7 @@ app = JupyterDash(__name__,external_stylesheets=external_stylesheets, external_s
 #======DESIGN THE APP===============
 
 app.layout = html.Div(children=[
-    html.H2("The ARMA model",
-            style={'textAlign': 'center', 'color': colors['text']}),
+    *make_top_banner("The ARMA model"),
     html.Div(children=[html.H4("ARMA Parameters"),
                        html.Table(children=[
                            app_parameter_row('c', 'c', 'number', 0),
@@ -518,7 +512,6 @@ app.layout = html.Div(children=[
                                                     ]),
                        html.Hr(),
                        html.Button('PLOT', id='execute',style={'textAlign': 'center', 'backgroundColor': colors['buttons']}),
-                       html.P('ARMA PROCESS DEMO', style={'textAlign': 'center', 'color': colors['text'],'marginTop':500}),
                        ],
              style={'textAlign': 'center', 'color': colors['controls'], 'width': '20%', 'display': 'inline-block'}),
 
@@ -545,8 +538,8 @@ app.layout = html.Div(children=[
                  # --PLOT 3b:  IMPULSE RESPONSE FUNCTION----------------------------------------------------------------
                  dcc.Graph(id='plot-ma-roots',
                            style={'width': '30%', 'float': 'left', 'display': 'inline-block'}),
-                 html.A(children='Randall Romero Aguilar', href='http://randall-romero.com', style={'textAlign': 'center', 'color': colors['text'],'marginBottom':60}),
              ]),
+    make_bottom_banner('macrodemos.ARMA_demo( )', width=20)
 ],
 style={'backgroundColor': colors['background']})
 
@@ -636,7 +629,7 @@ def ARMA_demo(colab=False):
         app.run_server(mode='external')
     else:
         webbrowser.open('http://127.0.0.1:8050/')
-        app.run_server(debug=True)
+        app.run_server(debug=False)
 
 
 if __name__ == '__main__':
