@@ -8,7 +8,8 @@ import plotly.express as px
 import webbrowser
 from warnings import warn
 
-from macrodemos.common_components import app_parameter_row, editable_cell_format, header_cell_format
+from macrodemos.common_components import app_parameter_row, editable_cell_format, header_cell_format, \
+    colors, make_top_banner, make_bottom_banner
 
 import numpy as np
 import pandas as pd
@@ -18,12 +19,7 @@ import pandas as pd
 # Esta parte controla asuntos de estética de la página
 external_stylesheets = ['https://codepen.io/chriddyp/pen/bWLwgP.css']
 
-colors = {
-    'background': 'SteelBlue',
-    'text': 'White',
-    'controls': '#DDDDDD',
-    'buttons': 'Orange'
-}
+
 
 
 
@@ -191,9 +187,7 @@ def make_the_app(states):
     # ======DESIGN THE APP===============
 
     app.layout = html.Div(children=[
-        html.H2(id='title',
-                children=f'Markov Chain with {n_states} states',
-                style={'textAlign': 'center', 'color': colors['text']}),
+        *make_top_banner(f'Markov Chain with {n_states} states'),
         html.Div(children=[html.H4("Transition matrix"),
                            dash_table.DataTable(
                                id='table-row-headers',
@@ -240,7 +234,6 @@ def make_the_app(states):
                            ]),
                            html.Button('PLOT', id='execute'
                                        ,style={'textAlign': 'center', 'backgroundColor': colors['buttons']}),
-                           html.P('Markov-Chain-DEMO', style={'textAlign': 'center', 'color': colors['text'] ,'marginTop' :270}),
                            ],
                  style={'textAlign': 'center', 'color': colors['controls'], 'width': '25%', 'display': 'inline-block'}),
 
@@ -252,8 +245,8 @@ def make_the_app(states):
                      # --PLOT 1b:  output per capita ------------------------------------------------------------------------------
                      dcc.Graph(id='plot-output',
                                style={'width': '100%',  'display': 'inline-block'}),
-                     html.A(children='Randall Romero Aguilar', href='http://randall-romero.com', style={'textAlign': 'center', 'color': colors['text'] ,'marginBottom' :60}),
                  ]),
+        make_bottom_banner("macrodemos.Markov_demo('state 0', 'state 1',...,'state n')")
     ],
         style={'backgroundColor': colors['background']})
 
