@@ -18,7 +18,7 @@ So far, the demo works with national accounts data from only 2 countries
     2. United States
 
 Randall Romero Aguilar
-2016-2020
+2016-2021
 """
 
 
@@ -30,7 +30,8 @@ from dash.dependencies import Input, Output, State
 import plotly.graph_objects as go
 import plotly.express as px
 
-from macrodemos.common_components import app_parameter_row, app_choose_parameter
+from macrodemos.common_components import app_parameter_row, app_choose_parameter, \
+    colors, make_bottom_banner, make_top_banner
 
 from statsmodels.formula.api import ols
 import webbrowser
@@ -48,12 +49,6 @@ pd.core.common.is_list_like = pd.api.types.is_list_like
 
 external_stylesheets = ['https://codepen.io/chriddyp/pen/bWLwgP.css']
 
-colors = {
-    'background': 'SteelBlue',
-    'text': 'White',
-    'controls': '#DDDDDD',
-    'buttons': 'Orange'
-}
 
 
 """==========================================================================================================
@@ -316,10 +311,7 @@ This block builds the app layout
 app = JupyterDash(__name__,external_stylesheets=external_stylesheets, external_scripts=mathjax)
 
 app.layout = html.Div(children=[
-    html.H2(id='title',children='Filtering of historical time series data',
-            style={'textAlign': 'center', 'color': colors['text']}),
-    html.P(id='estimated',
-            style={'textAlign': 'center', 'color': colors['text']}),
+    *make_top_banner('Filtering of historical time series data'),
     html.Div(children=[html.H4("Choose Series"),
                        html.Table(children=[
                            app_choose_parameter('Country',
@@ -374,7 +366,6 @@ app.layout = html.Div(children=[
                                      value=['HP']
                                      ),
                        html.Button('PLOT', id='execute',style={'textAlign': 'center', 'backgroundColor': colors['buttons']}),
-                       html.P('TIME SERIES FILTER DEMO', style={'textAlign': 'center', 'color': colors['text'],'marginTop':115}),
                        ],
              style={'textAlign': 'center', 'color': colors['controls'], 'width': '20%', 'display': 'inline-block'}),
 
@@ -428,8 +419,8 @@ app.layout = html.Div(children=[
                                  """)]),
                              ]),
                  ]),
-                 html.A(children='Randall Romero Aguilar', href='mailto:randall.romero@ucr.ac.cr', style={'textAlign': 'center', 'color': colors['text'],'marginBottom':60}),
              ]),
+    make_bottom_banner('macrodemos.filters_demo( )', width=20)
 ],
     style={'backgroundColor': colors['background']})
 
